import { admin } from '@/access/admin'
import type { CollectionConfig } from 'payload'

const expirationInMinutes = parseInt(process.env.PASSWORD_RESET_EXPIRATION_IN_MINUTES || '30')
const domain = process.env.DOMAIN_NAME || 'localhost:3000'

export const Users: CollectionConfig = {
  slug: 'users',
  admin: {
    useAsTitle: 'email',
  },
  access: {
    admin: admin
  },
  auth: {
    //   verify: {
    //     generateEmailSubject: () => {
    //       return `Verify Account for ${domain}`
    //     },
    //     generateEmailHTML: ({ req, token, user }) => {
    //       const url = `https://${domain}/verify?token=${token}`
    //       return `
    //         <!doctype html>
    //         <html>
    //           <body>
    //             <h1>Verify Account for ${domain}</h1>
    //             <p>Hey ${user.email}, verify your email by clicking here: ${url}</p>
    //             <p>If you have not recently been signed up for ${domain} then please ignore this email.</p>
    //           </body>
    //         </html>
    //       `
    //     },
    //   },
    forgotPassword: {
      expiration: (60000 * expirationInMinutes),
      generateEmailSubject: () => {
        return `Reset password request for ${domain}`
      },
      generateEmailHTML: (props) => {
        const resetPasswordURL = `https://${domain}/forgotPassword?token=${props?.token}`

        return `
          <!doctype html>
          <html>
            <body>
              <h1>Reset Password for ${domain}</h1>
              <p>Hello, ${props?.user.firstName}!</p>
              <p>There has been a request for the account account for ${props?.user.email}. If this is not the case then please ignore this email.</p>
              <p>If you intend to reset your password then you can do so with the link below.</p>
              <p>
                <a href="${resetPasswordURL}">${resetPasswordURL}</a>
              </p>
            </body>
          </html>
        `
      },
    }
  },
  fields: [
    // Email added by default
    // Add more fields as needed
    {
      name: 'role',
      type: 'select',
      options: ['admin', 'user'],
      saveToJWT: true
    },
    {
      name: 'firstName',
      type: 'text',
    },
    {
      name: 'lastName',
      type: 'text',
    },
    {
      name: 'repositories',
      type: 'join',
      collection: 'repositories',
      on: 'owner',
    },
    {
      name: 'profilePicture',
      type: 'relationship',
      relationTo: 'media',
    },
  ],
}
